@@ -86,11 +86,9 @@ static unsigned long thread_id(void)
 
 static void init_ssl_locks(void)
 {
-	int i;
-
 	lockarray = (pthread_mutex_t *) OPENSSL_malloc(CRYPTO_num_locks() *
 	                sizeof(pthread_mutex_t));
-	for (i = 0; i < CRYPTO_num_locks(); i++)
+	for (int i = 0; i < CRYPTO_num_locks(); i++)
 		pthread_mutex_init(&lockarray[i], NULL);
 	CRYPTO_set_id_callback((unsigned long (*)()) thread_id);
 	CRYPTO_set_locking_callback((void (*)()) lock_callback);
@@ -98,10 +96,8 @@ static void init_ssl_locks(void)
 
 static void destroy_ssl_locks(void)
 {
-	int i;
-
 	CRYPTO_set_locking_callback(NULL);
-	for (i = 0; i < CRYPTO_num_locks(); i++)
+	for (int i = 0; i < CRYPTO_num_locks(); i++)
 		pthread_mutex_destroy(&lockarray[i]);
 	OPENSSL_free(lockarray);
 	lockarray = NULL;
@@ -405,7 +401,7 @@ static inline void set_tunnel_ips(struct tunnel *tunnel,
 static void debug_bad_packet(struct tunnel *tunnel, uint8_t *header)
 {
 	uint8_t buffer[256];
-	int size, i;
+	int size;
 
 	memcpy(buffer, header, 6 * sizeof(uint8_t));
 
@@ -418,16 +414,16 @@ static void debug_bad_packet(struct tunnel *tunnel, uint8_t *header)
 	do_log_packet("  (hex) ", size, buffer);
 
 	// then print the raw string, after escaping non-displayable chars
-	for (i = 0; i < size; i++)
+	for (int i = 0; i < size; i++)
 		if (!printable_char((char) buffer[i]))
 			buffer[i] = '.';
-	buffer[i] = buffer[256 - 1] = '\0';
+	buffer[size] = buffer[256 - 1] = '\0';
 
 	printf("  (raw) %s\n", (const char *) buffer);
 }
 
 /*
- * Thread to read bytes from the SSL socket, convert them to ppp packets and add
+ * Thread to read bytes from the TLS socket, convert them to ppp packets and add
  * them to the 'ssl_to_pty' pool.
  */
 static void *ssl_read(void *arg)
@@ -446,14 +442,14 @@ static void *ssl_read(void *arg)
 
 		ret = safe_ssl_read_all(tunnel->ssl_handle, header, 6);
 		if (ret < 0) {
-			log_debug("Error reading from SSL connection (%s).\n",
+			log_debug("Error reading from TLS connection (%s).\n",
 			          err_ssl_str(ret));
 			break;
 		}
 
 		if (memcmp(header, http_header, 6) == 0) {
 			/*
-			 * When the SSL-VPN portal has not been set up to allow
+			 * When the TLS-VPN portal has not been set up to allow
 			 * tunnel mode for VPN clients, while it allows web mode
 			 * for web browsers, it returns an HTTP error instead of
 			 * a PPP packet:
@@ -483,7 +479,7 @@ static void *ssl_read(void *arg)
 		ret = safe_ssl_read_all(tunnel->ssl_handle, pkt_data(packet),
 		                        size);
 		if (ret < 0) {
-			log_debug("Error reading from SSL connection (%s).\n",
+			log_debug("Error reading from TLS connection (%s).\n",
 			          err_ssl_str(ret));
 			free(packet);
 			break;
@@ -525,7 +521,7 @@ static void *ssl_read(void *arg)
 }
 
 /*
- * Thread to pop packets from the 'pty_to_ssl' pool, and write them to the SSL
+ * Thread to pop packets from the 'pty_to_ssl' pool, and write them to the TLS
  * socket.
  */
 static void *ssl_write(void *arg)
@@ -553,7 +549,7 @@ static void *ssl_write(void *arg)
 			                     packet->content, 6 + packet->len);
 		} while (ret == 0);
 		if (ret < 0) {
-			log_debug("Error writing to SSL connection (%s).\n",
+			log_debug("Error writing to TLS connection (%s).\n",
 			          err_ssl_str(ret));
 			free(packet);
 			break;
@@ -567,7 +563,7 @@ static void *ssl_write(void *arg)
 }
 
 /*
- * Thread to pop packets from the 'pty_to_ssl' pool, and write them to the SSL
+ * Thread to pop packets from the 'pty_to_ssl' pool, and write them to the TLS
  * socket.
  */
 static void *if_config(void *arg)
