@@ -54,30 +54,38 @@
 #define ERESTART -1
 #endif
 
-#define ERR_SSL_AGAIN		0
-#define ERR_SSL_CLOSED		-1
-#define ERR_SSL_CERT		-2
-#define ERR_SSL_EOF		-3
-#define ERR_SSL_PROTOCOL	-4
-#define ERR_SSL_SEE_ERRNO	-5
-#define ERR_SSL_SEE_SSLERR	-6
-#define ERR_SSL_UNKNOWN		-7
+#define ERR_SSL_AGAIN		 0 // deprecated
+#define ERR_TLS_AGAIN		 0
+#define ERR_SSL_CLOSED		-1 // deprecated
+#define ERR_TLS_CLOSED		-1
+#define ERR_SSL_CERT		-2 // deprecated
+#define ERR_TLS_CERT		-2
+#define ERR_SSL_EOF		-3 // deprecated
+#define ERR_TLS_EOF		-3
+#define ERR_SSL_PROTOCOL	-4 // deprecated
+#define ERR_TLS_PROTOCOL	-4
+#define ERR_SSL_SEE_ERRNO	-5 // deprecated
+#define ERR_TLS_SEE_ERRNO	-5
+#define ERR_SSL_SEE_TLSERR	-6 // deprecated
+#define ERR_TLS_SEE_TLSERR	-6
+#define ERR_SSL_UNKNOWN		-7 // deprecated
+#define ERR_TLS_UNKNOWN		-7
 
 static inline const char *err_ssl_str(int code)
 {
-	if (code == ERR_SSL_AGAIN)
+	if (code == ERR_TLS_AGAIN)
 		return "Try again";
-	else if (code == ERR_SSL_CLOSED)
+	else if (code == ERR_TLS_CLOSED)
 		return "Connection closed";
-	else if (code == ERR_SSL_CERT)
+	else if (code == ERR_TLS_CERT)
 		return "Want X509 lookup";
-	else if (code == ERR_SSL_EOF)
+	else if (code == ERR_TLS_EOF)
 		return "Protocol violation with EOF";
-	else if (code == ERR_SSL_PROTOCOL)
+	else if (code == ERR_TLS_PROTOCOL)
 		return "Protocol error";
-	else if (code == ERR_SSL_SEE_ERRNO)
+	else if (code == ERR_TLS_SEE_ERRNO)
 		return strerror(errno);
-	else if (code == ERR_SSL_SEE_SSLERR)
+	else if (code == ERR_TLS_SEE_TLSERR)
 		return ERR_reason_error_string(ERR_peek_last_error());
 	return "unknown";
 }
@@ -87,65 +95,59 @@ static inline int handle_ssl_error(SSL *ssl, int ret)
 	int code;
 
 	if (SSL_get_shutdown(ssl) & SSL_RECEIVED_SHUTDOWN)
-		return ERR_SSL_CLOSED;
+		return ERR_TLS_CLOSED;
 
 	code = SSL_get_error(ssl, ret);
 	if (code == SSL_ERROR_WANT_READ || code == SSL_ERROR_WANT_WRITE)
-		return ERR_SSL_AGAIN; // The caller should try again
+		return ERR_TLS_AGAIN; // The caller should try again
 
 	if (code == SSL_ERROR_ZERO_RETURN)
-		return ERR_SSL_CLOSED;
+		return ERR_TLS_CLOSED;
 	if (code == SSL_ERROR_WANT_X509_LOOKUP)
-		return ERR_SSL_CERT;
+		return ERR_TLS_CERT;
 	if (code == SSL_ERROR_SYSCALL) {
 		if (ERR_peek_last_error() != 0)
-			return ERR_SSL_SEE_SSLERR;
+			return ERR_TLS_SEE_TLSERR;
 		if (ret == 0)
-			return ERR_SSL_EOF;
+			return ERR_TLS_EOF;
 		if (errno == EAGAIN || errno == ERESTART || errno == EINTR)
-			return ERR_SSL_AGAIN; // The caller should try again
+			return ERR_TLS_AGAIN; // The caller should try again
 		if (errno == EPIPE)
-			return ERR_SSL_CLOSED;
-		return ERR_SSL_SEE_ERRNO;
+			return ERR_TLS_CLOSED;
+		return ERR_TLS_SEE_ERRNO;
 	}
 	if (code == SSL_ERROR_SSL)
-		return ERR_SSL_PROTOCOL;
-	return ERR_SSL_UNKNOWN;
+		return ERR_TLS_PROTOCOL;
+	return ERR_TLS_UNKNOWN;
 }
 
 /*
- * Reads data from the SSL connection.
+ * Reads data from the TLS connection.
  *
  * @return  > 0            in case of success (number of bytes transferred)
- *          ERR_SSL_AGAIN  if the caller should try again
+ *          ERR_TLS_AGAIN  if the caller should try again
  *          < 0            in case of error
  */
 static inline int safe_ssl_read(SSL *ssl, uint8_t *buf, int bufsize)
 {
-	int ret;
+	int ret = SSL_read(ssl, buf, bufsize);
 
-	ret = SSL_read(ssl, buf, bufsize);
-	if (ret > 0)
-		return ret;
-
-	return handle_ssl_error(ssl, ret);
+	return (ret > 0) ? ret : handle_ssl_error(ssl, ret);
 }
 
 /*
- * Reads all data from the SSL connection.
+ * Reads all data from the TLS connection.
  *
  * @return  1    in case of success
  *          < 0  in case of error
  */
 static inline int safe_ssl_read_all(SSL *ssl, uint8_t *buf, int bufsize)
 {
-	int n = 0;
-
-	while (n < bufsize) {
+	for (int n = 0; n < bufsize; ) {
 		int ret;
 
 		ret = safe_ssl_read(ssl, &buf[n], bufsize - n);
-		if (ret == ERR_SSL_AGAIN)
+		if (ret == ERR_TLS_AGAIN)
 			continue;
 		else if (ret < 0)
 			return ret;
@@ -155,25 +157,21 @@ static inline int safe_ssl_read_all(SSL *ssl, uint8_t *buf, int bufsize)
 }
 
 /*
- * Writes data to the SSL connection.
+ * Writes data to the TLS connection.
  *
  * Since SSL_MODE_ENABLE_PARTIAL_WRITE is not set by default (see man
  * SSL_get_mode), SSL_write() will only report success once the complete chunk
  * has been written.
  *
  * @return  > 0            in case of success (number of bytes transferred)
- *          ERR_SSL_AGAIN  if the caller should try again
+ *          ERR_TLS_AGAIN  if the caller should try again
  *          < 0            in case of error
  */
 static inline int safe_ssl_write(SSL *ssl, const uint8_t *buf, int n)
 {
-	int ret;
+	int ret = SSL_write(ssl, buf, n);
 
-	ret = SSL_write(ssl, buf, n);
-	if (ret > 0)
-		return ret;
-
-	return handle_ssl_error(ssl, ret);
+	return (ret > 0) ? ret : handle_ssl_error(ssl, ret);
 }
 
 #endif
